@@ -118,7 +118,10 @@ thunar_dialogs_show_rename_file (gpointer    parent,
   g_object_unref (G_OBJECT (icon_factory));
 
   image = gtk_image_new_from_pixbuf (icon);
-  gtk_misc_set_padding (GTK_MISC (image), 6, 6);
+  gtk_widget_set_margin_start (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_end (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_top (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_bottom (GTK_WIDGET(image), 6);
   gtk_grid_attach (GTK_GRID (grid), image, 0, 0, 1, 2);
   g_object_unref (G_OBJECT (icon));
   gtk_widget_show (image);
@@ -308,7 +311,7 @@ thunar_dialogs_show_error (gpointer      parent,
   _thunar_return_if_fail (parent == NULL || GDK_IS_SCREEN (parent) || GTK_IS_WIDGET (parent));
 
   /* do not display error dialog for already handled errors */
-  if (error->code == G_IO_ERROR_FAILED_HANDLED)
+  if (error && error->code == G_IO_ERROR_FAILED_HANDLED)
     return;
 
   /* parse the parent pointer */
@@ -573,7 +576,10 @@ thunar_dialogs_show_job_ask_replace (GtkWindow  *parent,
   image = gtk_image_new_from_icon_name ("stock_folder-copy", GTK_ICON_SIZE_BUTTON);
   gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (image, GTK_ALIGN_START);
-  gtk_misc_set_padding (GTK_MISC (image), 6, 6);
+  gtk_widget_set_margin_start (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_end (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_top (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_bottom (GTK_WIDGET(image), 6);
   gtk_widget_set_vexpand (image, TRUE);
   gtk_grid_attach (GTK_GRID (grid), image, 0, 0, 1, 1);
   gtk_widget_show (image);
@@ -618,12 +624,15 @@ thunar_dialogs_show_job_ask_replace (GtkWindow  *parent,
 
   icon = thunar_icon_factory_load_file_icon (icon_factory, dst_file, THUNAR_FILE_ICON_STATE_DEFAULT, 48);
   image = gtk_image_new_from_pixbuf (icon);
-  gtk_misc_set_padding (GTK_MISC (image), 6, 6);
+  gtk_widget_set_margin_start (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_end (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_top (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_bottom (GTK_WIDGET(image), 6);
   gtk_grid_attach (GTK_GRID (grid), image, 1, 2, 1, 1);
   g_object_unref (G_OBJECT (icon));
   gtk_widget_show (image);
 
-  size_string = thunar_file_get_size_string_formatted (dst_file, file_size_binary);
+  size_string = thunar_file_get_size_string_long (dst_file, file_size_binary);
   date_string = thunar_file_get_date_string (dst_file, THUNAR_FILE_DATE_MODIFIED, date_style);
   text = g_strdup_printf ("%s %s\n%s %s", _("Size:"), size_string, _("Modified:"), date_string);
   label = gtk_label_new (text);
@@ -651,12 +660,15 @@ thunar_dialogs_show_job_ask_replace (GtkWindow  *parent,
 
   icon = thunar_icon_factory_load_file_icon (icon_factory, src_file, THUNAR_FILE_ICON_STATE_DEFAULT, 48);
   image = gtk_image_new_from_pixbuf (icon);
-  gtk_misc_set_padding (GTK_MISC (image), 6, 6);
+  gtk_widget_set_margin_start (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_end (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_top (GTK_WIDGET(image), 6);
+  gtk_widget_set_margin_bottom (GTK_WIDGET(image), 6);
   gtk_grid_attach (GTK_GRID (grid), image, 1, 4, 1, 1);
   g_object_unref (G_OBJECT (icon));
   gtk_widget_show (image);
 
-  size_string = thunar_file_get_size_string_formatted (src_file, file_size_binary);
+  size_string = thunar_file_get_size_string_long (src_file, file_size_binary);
   date_string = thunar_file_get_date_string (src_file, THUNAR_FILE_DATE_MODIFIED, date_style);
   text = g_strdup_printf ("%s %s\n%s %s", _("Size:"), size_string, _("Modified:"), date_string);
   label = gtk_label_new (text);
