@@ -1,4 +1,4 @@
-/* $Id$ */
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
  *
@@ -44,7 +44,6 @@ enum
 
 
 static void       thunar_emblem_chooser_dispose         (GObject                   *object);
-static void       thunar_emblem_chooser_finalize        (GObject                   *object);
 static void       thunar_emblem_chooser_get_property    (GObject                   *object,
                                                          guint                      prop_id,
                                                          GValue                    *value,
@@ -79,7 +78,6 @@ struct _ThunarEmblemChooser
   GtkScrolledWindow __parent__;
 
   GtkIconTheme *icon_theme;
-  GtkSizeGroup *size_group;
   GList        *files;
   GtkWidget    *table;
 };
@@ -98,7 +96,6 @@ thunar_emblem_chooser_class_init (ThunarEmblemChooserClass *klass)
 
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->dispose = thunar_emblem_chooser_dispose;
-  gobject_class->finalize = thunar_emblem_chooser_finalize;
   gobject_class->get_property = thunar_emblem_chooser_get_property;
   gobject_class->set_property = thunar_emblem_chooser_set_property;
 
@@ -138,12 +135,13 @@ thunar_emblem_chooser_init (ThunarEmblemChooser *chooser)
   gtk_widget_show (viewport);
 
   /* setup the wrap table */
-  chooser->table = g_object_new (EXO_TYPE_WRAP_TABLE, "border-width", 6, "homogeneous", TRUE, NULL);
+  chooser->table = g_object_new (GTK_TYPE_FLOW_BOX,
+                                 "homogeneous", TRUE,
+                                 "column-spacing", 12,
+                                 "row-spacing", 12,
+                                 NULL);
   gtk_container_add (GTK_CONTAINER (viewport), chooser->table);
   gtk_widget_show (chooser->table);
-
-  /* allocate a size-group for the buttons */
-  chooser->size_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
 }
 
 
@@ -161,19 +159,6 @@ thunar_emblem_chooser_dispose (GObject *object)
 
 
 
-static void
-thunar_emblem_chooser_finalize (GObject *object)
-{
-  ThunarEmblemChooser *chooser = THUNAR_EMBLEM_CHOOSER (object);
-
-  /* release the size-group */
-  g_object_unref (G_OBJECT (chooser->size_group));
-
-  (*G_OBJECT_CLASS (thunar_emblem_chooser_parent_class)->finalize) (object);
-}
-
-
-
 static void
 thunar_emblem_chooser_get_property (GObject    *object,
                                     guint       prop_id,
@@ -328,6 +313,7 @@ thunar_emblem_chooser_file_changed (ThunarEmblemChooser *chooser)
   GList       *file_emblems;
   GList       *children;
   GList       *lp, *li;
+  GObject     *child;
   guint       *count;
   guint        n_files = 0;
 
@@ -358,22 +344,26 @@ thunar_emblem_chooser_file_changed (ThunarEmblemChooser *chooser)
   children = gtk_container_get_children (GTK_CONTAINER (chooser->table));
   for (lp = children; lp != NULL; lp = lp->next)
     {
-      emblem_name = g_object_get_data (G_OBJECT (lp->data), I_("thunar-emblem"));
+      child = G_OBJECT (lp->data);
+      if (GTK_IS_FLOW_BOX_CHILD (child))
+        child = G_OBJECT (gtk_bin_get_child (GTK_BIN (child)));
+
+      emblem_name = g_object_get_data (child, I_("thunar-emblem"));
       count = g_hash_table_lookup (emblem_names, emblem_name);
 
-      g_signal_handlers_block_by_func (lp->data, thunar_emblem_chooser_button_toggled, chooser);
+      g_signal_handlers_block_by_func (child, thunar_emblem_chooser_button_toggled, chooser);
 
       if (count == NULL || *count == n_files)
         {
-          gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (lp->data), FALSE);
-          gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (lp->data), count != NULL);
+          gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (child), FALSE);
+          gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (child), count != NULL);
         }
       else
         {
-          gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (lp->data), TRUE);
+          gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (child), TRUE);
         }
 
-      g_signal_handlers_unblock_by_func (lp->data, thunar_emblem_chooser_button_toggled, chooser);
+      g_signal_handlers_unblock_by_func (child, thunar_emblem_chooser_button_toggled, chooser);
     }
   g_list_free (children);
 
@@ -448,8 +438,6 @@ thunar_emblem_chooser_create_button (ThunarEmblemChooser *chooser,
   const gchar *name;
   GtkWidget   *button = NULL;
   GtkWidget   *image;
-  GtkWidget   *label;
-  GtkWidget   *vbox;
   GdkPixbuf   *icon;
 
   /* lookup the icon info for the emblem */
@@ -473,25 +461,15 @@ thunar_emblem_chooser_create_button (ThunarEmblemChooser *chooser,
   g_object_set_data_full (G_OBJECT (button), I_("thunar-emblem"), g_strdup (emblem), g_free);
   g_signal_connect (G_OBJECT (button), "toggled", G_CALLBACK (thunar_emblem_chooser_button_toggled), chooser);
 
-  /* allocate the box */
-  vbox = gtk_vbox_new (FALSE, 2);
-  gtk_size_group_add_widget (chooser->size_group, vbox);
-  gtk_container_add (GTK_CONTAINER (button), vbox);
-  gtk_widget_show (vbox);
-
   /* allocate the image */
   image = gtk_image_new_from_pixbuf (icon);
-  gtk_box_pack_start (GTK_BOX (vbox), image, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (button), image);
+  gtk_widget_set_tooltip_text (image, name);
   gtk_widget_show (image);
 
-  /* allocate the label */
-  label = gtk_label_new (name);
-  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-  gtk_widget_show (label);
-
   g_object_unref (G_OBJECT (icon));
 done:
-  gtk_icon_info_free (info);
+  g_object_unref (info);
   return button;
 }
 
