@@ -172,6 +172,9 @@ static gint               sort_by_permissions                     (const ThunarF
 static gint               sort_by_size                            (const ThunarFile       *a,
                                                                    const ThunarFile       *b,
                                                                    gboolean                case_sensitive);
+static gint               sort_by_size_in_bytes                   (const ThunarFile       *a,
+                                                                   const ThunarFile       *b,
+                                                                   gboolean                case_sensitive);
 static gint               sort_by_type                            (const ThunarFile       *a,
                                                                    const ThunarFile       *b,
                                                                    gboolean                case_sensitive);
@@ -594,6 +597,9 @@ thunar_list_model_get_column_type (GtkTreeModel *model,
     case THUNAR_COLUMN_SIZE:
       return G_TYPE_STRING;
 
+    case THUNAR_COLUMN_SIZE_IN_BYTES:
+      return G_TYPE_STRING;
+
     case THUNAR_COLUMN_TYPE:
       return G_TYPE_STRING;
 
@@ -722,7 +728,15 @@ thunar_list_model_get_value (GtkTreeModel *model,
           /* determine sane display name for the owner */
           name = thunar_user_get_name (user);
           real_name = thunar_user_get_real_name (user);
-          str = G_LIKELY (real_name != NULL) ? g_strdup_printf ("%s (%s)", real_name, name) : g_strdup (name);
+          if(G_LIKELY (real_name != NULL))
+            {
+              if(strcmp (name, real_name) == 0)
+                str = g_strdup (name);
+              else
+                str = g_strdup_printf ("%s (%s)", real_name, name);
+            }
+          else
+            str = g_strdup (name);
           g_value_take_string (value, str);
           g_object_unref (G_OBJECT (user));
         }
@@ -742,6 +756,11 @@ thunar_list_model_get_value (GtkTreeModel *model,
       g_value_take_string (value, thunar_file_get_size_string_formatted (file, THUNAR_LIST_MODEL (model)->file_size_binary));
       break;
 
+    case THUNAR_COLUMN_SIZE_IN_BYTES:
+      g_value_init (value, G_TYPE_STRING);
+      g_value_take_string (value, thunar_file_get_size_in_bytes_string (file));
+      break;
+
     case THUNAR_COLUMN_TYPE:
       g_value_init (value, G_TYPE_STRING);
       if (G_UNLIKELY (thunar_file_is_symlink (file)))
@@ -901,6 +920,8 @@ thunar_list_model_get_sort_column_id (GtkTreeSortable *sortable,
     *sort_column_id = THUNAR_COLUMN_PERMISSIONS;
   else if (store->sort_func == sort_by_size)
     *sort_column_id = THUNAR_COLUMN_SIZE;
+  else if (store->sort_func == sort_by_size_in_bytes)
+    *sort_column_id = THUNAR_COLUMN_SIZE_IN_BYTES;
   else if (store->sort_func == sort_by_date_accessed)
     *sort_column_id = THUNAR_COLUMN_DATE_ACCESSED;
   else if (store->sort_func == sort_by_date_modified)
@@ -971,6 +992,10 @@ thunar_list_model_set_sort_column_id (GtkTreeSortable *sortable,
       store->sort_func = sort_by_size;
       break;
 
+    case THUNAR_COLUMN_SIZE_IN_BYTES:
+      store->sort_func = sort_by_size_in_bytes;
+      break;
+
     case THUNAR_COLUMN_TYPE:
       store->sort_func = sort_by_type;
       break;
@@ -1554,6 +1579,16 @@ sort_by_size (const ThunarFile *a,
 
 
 
+static gint
+sort_by_size_in_bytes (const ThunarFile *a,
+                       const ThunarFile *b,
+                       gboolean          case_sensitive)
+{
+  return sort_by_size (a, b, case_sensitive);
+}
+
+
+
 static gint
 sort_by_type (const ThunarFile *a,
               const ThunarFile *b,
@@ -2289,8 +2324,8 @@ thunar_list_model_get_statusbar_text (ThunarListModel *store,
           if (size_summary > 0)
             {
               /* generate a text which includes the size of all items in the folder */
-              size_string = g_format_size_full (size_summary, file_size_binary ? G_FORMAT_SIZE_IEC_UNITS : G_FORMAT_SIZE_DEFAULT);
-              text = g_strdup_printf (ngettext ("%d item (%s), Free space: %s", "%d items (%s), Free space: %s", nrows),
+              size_string = g_format_size_full (size_summary, G_FORMAT_SIZE_LONG_FORMAT | (file_size_binary ? G_FORMAT_SIZE_IEC_UNITS : G_FORMAT_SIZE_DEFAULT));
+              text = g_strdup_printf (ngettext ("%d item: %s, Free space: %s", "%d items: %s, Free space: %s", nrows),
                                       nrows, size_string, fspace_string);
               g_free (size_string);
             }
@@ -2322,29 +2357,29 @@ thunar_list_model_get_statusbar_text (ThunarListModel *store,
 
       if (G_UNLIKELY (content_type != NULL && g_str_equal (content_type, "inode/symlink")))
         {
-          text = g_strdup_printf (_("\"%s\" broken link"), thunar_file_get_display_name (file));
+          text = g_strdup_printf (_("\"%s\": broken link"), thunar_file_get_display_name (file));
         }
       else if (G_UNLIKELY (thunar_file_is_symlink (file)))
         {
-          size_string = thunar_file_get_size_string_formatted (file, file_size_binary);
-          text = g_strdup_printf (_("\"%s\" (%s) link to %s"), thunar_file_get_display_name (file),
+          size_string = thunar_file_get_size_string_long (file, file_size_binary);
+          text = g_strdup_printf (_("\"%s\": %s link to %s"), thunar_file_get_display_name (file),
                                   size_string, thunar_file_get_symlink_target (file));
           g_free (size_string);
         }
       else if (G_UNLIKELY (thunar_file_get_kind (file) == G_FILE_TYPE_SHORTCUT))
         {
-          text = g_strdup_printf (_("\"%s\" shortcut"), thunar_file_get_display_name (file));
+          text = g_strdup_printf (_("\"%s\": shortcut"), thunar_file_get_display_name (file));
         }
       else if (G_UNLIKELY (thunar_file_get_kind (file) == G_FILE_TYPE_MOUNTABLE))
         {
-          text = g_strdup_printf (_("\"%s\" mountable"), thunar_file_get_display_name (file));
+          text = g_strdup_printf (_("\"%s\": mountable"), thunar_file_get_display_name (file));
         }
       else if (thunar_file_is_regular (file))
         {
           description = g_content_type_get_description (content_type);
-          size_string = thunar_file_get_size_string_formatted (file, file_size_binary);
+          size_string = thunar_file_get_size_string_long (file, file_size_binary);
           /* I18N, first %s is the display name of the file, 2nd the file size, 3rd the content type */
-          text = g_strdup_printf (_("\"%s\" (%s) %s"), thunar_file_get_display_name (file),
+          text = g_strdup_printf (_("\"%s\": %s %s"), thunar_file_get_display_name (file),
                                   size_string, description);
           g_free (description);
           g_free (size_string);
@@ -2353,7 +2388,7 @@ thunar_list_model_get_statusbar_text (ThunarListModel *store,
         {
           description = g_content_type_get_description (content_type);
           /* I18N, first %s is the display name of the file, second the content type */
-          text = g_strdup_printf (_("\"%s\" %s"), thunar_file_get_display_name (file), description);
+          text = g_strdup_printf (_("\"%s\": %s"), thunar_file_get_display_name (file), description);
           g_free (description);
         }
 
@@ -2421,19 +2456,19 @@ thunar_list_model_get_statusbar_text (ThunarListModel *store,
      /* text for the items in the folder */
      if (non_folder_count > 0)
         {
-          size_string = g_format_size_full (size_summary, file_size_binary ? G_FORMAT_SIZE_IEC_UNITS : G_FORMAT_SIZE_DEFAULT);
+          size_string = g_format_size_full (size_summary, G_FORMAT_SIZE_LONG_FORMAT | (file_size_binary ? G_FORMAT_SIZE_IEC_UNITS : G_FORMAT_SIZE_DEFAULT));
           if (folder_count > 0)
             {
               /* item count if there are also folders in the selection */
-              non_folder_text = g_strdup_printf (ngettext ("%d other item selected (%s)",
-                                                           "%d other items selected (%s)",
+              non_folder_text = g_strdup_printf (ngettext ("%d other item selected: %s",
+                                                           "%d other items selected: %s",
                                                            non_folder_count), non_folder_count, size_string);
             }
           else
             {
               /* only non-folders are selected */
-              non_folder_text = g_strdup_printf (ngettext ("%d item selected (%s)",
-                                                           "%d items selected (%s)",
+              non_folder_text = g_strdup_printf (ngettext ("%d item selected: %s",
+                                                           "%d items selected: %s",
                                                            non_folder_count), non_folder_count, size_string);
             }
           g_free (size_string);
