@@ -643,7 +643,7 @@ thunar_shortcuts_view_drag_data_received (GtkWidget        *widget,
                         {
                           /* ask the user what to do with the drop data */
                           if (G_UNLIKELY (action == GDK_ACTION_ASK))
-                            action = thunar_dnd_ask (widget, file, view->drop_file_list, timestamp, actions);
+                            action = thunar_dnd_ask (widget, file, view->drop_file_list, actions);
 
                           /* perform the requested action */
                           if (G_LIKELY (action != 0))
@@ -1041,10 +1041,8 @@ thunar_shortcuts_view_context_menu_visibility (ThunarShortcutsView *view,
 
   gtk_tree_path_free (path);
 
-  /* run the menu on the view's screen (taking over the floating reference on menu) */
-  thunar_gtk_menu_run (GTK_MENU (menu), GTK_WIDGET (view), NULL, NULL,
-                       (event != NULL) ? event->button : 0,
-                       (event != NULL) ? event->time : gtk_get_current_event_time ());
+  /* run the menu (taking over the floating reference on menu) */
+  thunar_gtk_menu_run (GTK_MENU (menu));
 }
 
 
@@ -1103,8 +1101,8 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   gtk_widget_show (item);
 
-  /* set the stock icon */
-  image = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
+  /* set the icon */
+  image = gtk_image_new_from_icon_name ("document-open", GTK_ICON_SIZE_MENU);
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 
   /* append the "Open in New Tab" menu action */
@@ -1265,8 +1263,8 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
       gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
       gtk_widget_show (item);
 
-      /* set the remove stock icon */
-      image = gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU);
+      /* set the remove icon */
+      image = gtk_image_new_from_icon_name ("list-remove", GTK_ICON_SIZE_MENU);
       gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 
       /* append the rename menu item */
@@ -1288,9 +1286,8 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
     g_object_unref (G_OBJECT (device));
   gtk_tree_path_free (path);
 
-  /* run the menu on the view's screen (taking over the floating reference on menu) */
-  thunar_gtk_menu_run (GTK_MENU (menu), GTK_WIDGET (view), NULL, NULL, (event != NULL) ? event->button : 0,
-                       (event != NULL) ? event->time : gtk_get_current_event_time ());
+  /* run the menu (taking over the floating reference on menu) */
+  thunar_gtk_menu_run (GTK_MENU (menu));
 }
 
 
